@@ -3,6 +3,7 @@ __all__ = [
     "LLMModel",
     "LiteLLMModel",
     "PassThroughRouter",
+    "extract_top_logprobs",
     "rate_limited",
     "request_limited",
     "sum_logprobs",
@@ -75,6 +76,8 @@ class CommonLLMNames(StrEnum):
     """When you don't want to think about models, just use one from here."""
 
     # Use these to avoid thinking about exact versions
+    GPT_5 = "gpt-5-2025-08-07"
+    GPT_5_MINI = "gpt-5-mini-2025-08-07"
     GPT_4O = "gpt-4o-2024-11-20"
     GPT_35_TURBO = "gpt-3.5-turbo-0125"
     CLAUDE_35_SONNET = "claude-3-5-sonnet-20241022"
@@ -116,6 +119,24 @@ def sum_logprobs(choice: litellm.utils.Choices | list[float]) -> float | None:
     return None
 
 
+def extract_top_logprobs(
+    completion: litellm.utils.Choices,
+) -> list[list[tuple[str, float]]] | None:
+    """Extract the top logprobs from an litellm completion."""
+    logprobs_obj = getattr(completion, "logprobs", None)
+    if logprobs_obj is None:
+        return None
+
+    content = getattr(logprobs_obj, "content", None)
+    if not content or not isinstance(content, list):
+        return None
+
+    return [
+        [(t.token, float(t.logprob)) for t in (getattr(pos, "top_logprobs", []) or [])]
+        for pos in content
+    ]
+
+
 def validate_json_completion(
     completion: litellm.ModelResponse,
     output_type: type[BaseModel] | TypeAdapter | JSONSchema,
@@ -566,6 +587,15 @@ class LiteLLMModel(LLMModel):
         if "name" not in data:
             data["name"] = data["config"].get("name", cls.model_fields["name"].default)
         if "model_list" not in data["config"]:
+            is_openai_model = "openai" in litellm.get_llm_provider(data["name"])
+            max_tokens = data["config"].get("max_tokens")
+            if (
+                "logprobs" in data["config"] or "top_logprobs" in data["config"]
+            ) and not is_openai_model:
+                logger.warning(
+                    "Ignoring token logprobs for non-OpenAI model %s, as they are not supported.",
+                    data["name"],
+                )
             data["config"] = {
                 "model_list": [
                     {
@@ -582,6 +612,19 @@ class LiteLLMModel(LLMModel):
                                 if "gemini" not in data["name"]
                                 else {"safety_settings": DEFAULT_VERTEX_SAFETY_SETTINGS}
                             )
+                            | ({} if max_tokens else {"max_tokens": max_tokens})
+                            | (
+                                {}
+                                if "logprobs" not in data["config"]
+                                or not is_openai_model
+                                else {"logprobs": data["config"]["logprobs"]}
+                            )
+                            | (
+                                {}
+                                if "top_logprobs" not in data["config"]
+                                or not is_openai_model
+                                else {"top_logprobs": data["config"]["top_logprobs"]}
+                            )
                         ),
                     }
                 ],
@@ -706,6 +749,7 @@ class LiteLLMModel(LLMModel):
                     prompt=messages,
                     messages=output_messages,
                     logprob=sum_logprobs(completion),
+                    top_logprobs=extract_top_logprobs(completion),
                     prompt_count=completions.usage.prompt_tokens,  # type: ignore[attr-defined]
                     completion_count=completions.usage.completion_tokens,  # type: ignore[attr-defined]
                     system_fingerprint=completions.system_fingerprint,
@@ -765,6 +809,7 @@ class LiteLLMModel(LLMModel):
             prompt=messages,
             messages=[Message(role=role, content=text)],
             logprob=sum_logprobs(logprobs),
+            top_logprobs=extract_top_logprobs(completion),
             reasoning_content="".join(reasoning_content),
         )
 
